==> chromium-browser_25.0.1364.160.orig.tar.xz: chromium-browser-25.0.1364.160/src/chrome/browser/extensions/extension_input_module_constants.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/extensions/extension_input_module_constants.h"

namespace extension_input_module_constants {

const char kAnnotationKey[] = "annotation";
const char kAuxiliaryTextKey[] = "auxiliaryText";
const char kAuxiliaryTextVisibleKey[] = "auxiliaryTextVisible";
const char kCandidateIdKey[] = "candidateID";
const char kCandidateKey[] = "candidate";
const char kCandidatesKey[] = "candidates";
const char kCheckedKey[] = "checked";
const char kContextIdKey[] = "contextID";
const char kCursorKey[] = "cursor";
const char kCursorVisibleKey[] = "cursorVisible";
const char kEnabledKey[] = "enabled";
const char kEndKey[] = "end";
const char kEngineIdKey[] = "engineID";
const char kIdKey[] = "id";
const char kItemsKey[] = "items";
const char kKeyKey[] = "key";
const char kLabelKey[] = "label";
const char kPageSizeKey[] = "pageSize";
const char kParentIdKey[] = "parentId";
const char kPropertiesKey[] = "properties";
const char kSegmentsKey[] = "segments";
const char kSelectionEndKey[] = "selectionEnd";
const char kSelectionStartKey[] = "selectionStart";
const char kStartKey[] = "start";
const char kStyleDoubleUnderline[] = "doubleUnderline";
const char kStyleKey[] = "style";
const char kStyleUnderline[] = "underline";
const char kTextKey[] = "text";
const char kUsageBodyKey[] = "body";
const char kUsageKey[] = "usage";
const char kUsageTitleKey[] = "title";
const char kVerticalKey[] = "vertical";
const char kVisibleKey[] = "visible";

}  // namespace extension_input_module_constants

==> chromium-browser_29.0.1547.65.orig.tar.xz: chromium-browser-29.0.1547.65/src/chrome/browser/extensions/extension_input_module_constants.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/extensions/extension_input_module_constants.h"

namespace extension_input_module_constants {

const char kAnnotationKey[] = "annotation";
const char kAuxiliaryTextKey[] = "auxiliaryText";
const char kAuxiliaryTextVisibleKey[] = "auxiliaryTextVisible";
const char kCandidateIdKey[] = "candidateID";
const char kCandidateKey[] = "candidate";
const char kCandidatesKey[] = "candidates";
const char kCheckedKey[] = "checked";
const char kContextIdKey[] = "contextID";
const char kCursorKey[] = "cursor";
const char kCursorVisibleKey[] = "cursorVisible";
const char kEnabledKey[] = "enabled";
const char kEndKey[] = "end";
const char kEngineIdKey[] = "engineID";
const char kIdKey[] = "id";
const char kItemsKey[] = "items";
const char kKeyKey[] = "key";
const char kLabelKey[] = "label";
const char kLengthKey[] = "length";
const char kOffsetKey[] = "offset";
const char kPageSizeKey[] = "pageSize";
const char kParentIdKey[] = "parentId";
const char kPropertiesKey[] = "properties";
const char kSegmentsKey[] = "segments";
const char kSelectionEndKey[] = "selectionEnd";
const char kSelectionStartKey[] = "selectionStart";
const char kStartKey[] = "start";
const char kStyleDoubleUnderline[] = "doubleUnderline";
const char kStyleKey[] = "style";
const char kStyleUnderline[] = "underline";
const char kTextKey[] = "text";
const char kUsageBodyKey[] = "body";
const char kUsageKey[] = "usage";
const char kUsageTitleKey[] = "title";
const char kVerticalKey[] = "vertical";
const char kVisibleKey[] = "visible";
const char kWindowPositionKey[] = "windowPosition";

}  // namespace extension_input_module_constants
